aiscalator.airflow package
==========================

Submodules
----------

aiscalator.airflow.airflow\_command module
------------------------------------------

.. automodule:: aiscalator.airflow.airflow_command
    :members:
    :undoc-members:
    :show-inheritance:

aiscalator.airflow.cli module
-----------------------------

.. automodule:: aiscalator.airflow.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: aiscalator.airflow
    :members:
    :undoc-members:
    :show-inheritance:
